@@ -115,7 +115,7 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
+#define HAVE_HIST_ENTRY 1
 /* #undef USE_LIBEDIT_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 
@@ -211,7 +211,7 @@
 #define HAVE_RENAME 1
 /* #undef HAVE_RWLOCK_INIT */
 #define HAVE_SCHED_YIELD 1
-#define HAVE_SELECT 1
+/* #undef HAVE_SELECT */
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
 /* #undef HAVE_SETMNTENT */
@@ -278,10 +278,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define HAVE_LONG 1
@@ -296,7 +296,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -334,7 +334,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -394,8 +394,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "sparc64"
-#define DEFAULT_MACHINE "sparc64"
+#define MACHINE_TYPE "earmv7hf"
+#define DEFAULT_MACHINE "earmv7hf"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -526,16 +526,16 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 
 #define MYSQL_VERSION_MAJOR 11
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 7
+#define MYSQL_VERSION_PATCH 8
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.4.7"
+#define PACKAGE_STRING "MySQL Server 11.4.8"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.4.7"
-#define VERSION "11.4.7"
+#define PACKAGE_VERSION "11.4.8"
+#define VERSION "11.4.8"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -549,7 +549,6 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 #ifndef EMBEDDED_LIBRARY
 /* #undef WSREP_INTERFACE_VERSION */
 /* #undef WITH_WSREP */
-/* #undef WSREP_PROC_INFO */
 #endif
 
 #if !defined(__STDC_FORMAT_MACROS)
